=========
Changelog
=========

All notable changes to `SandPaper <https://github.com/stephen-bunn/sandpaper/>`_ will be documented in this file.

The format is based on `Keep a Changelog <http://keepachangelog.com/en/1.0.0/>`_ and this project adheres to `Semantic Versioning <http://semver.org/spec/v2.0.0.html>`_.

`0.0.4`_ (*unreleased*)
-----------------------


`0.0.3`_ (*2017-10-24*)
-----------------------
* adding more badges to documentation and the README
* fixing (hopefully) the building of documentation for readthedocs.io
* fixing README example with an example that acutally makes sense


`0.0.2`_ (*2017-10-24*)
-----------------------
* adding even more badges to the README
* adding documentation improvements (linking rules to function references)
* adding several small improvements to the tests (better code coverage)


`0.0.1`_ (*2017-10-24*)
-----------------------
* added README formatting fixes for PyPi
* fixed the PyPi configuration issues in setup.py


`0.0.0`_ (*2017-10-24*)
-----------------------
* added the project's base structure (wish i could include change logs for prior structure updates)
* fixed the project's base structure for PY2 compatability


.. _0.0.4: https://github.com/stephen-bunn/sandpaper/
.. _0.0.3: https://github.com/stephen-bunn/sandpaper/releases/tag/v0.0.3
.. _0.0.2: https://github.com/stephen-bunn/sandpaper/releases/tag/v0.0.2
.. _0.0.1: https://github.com/stephen-bunn/sandpaper/releases/tag/v0.0.1
.. _0.0.0: https://github.com/stephen-bunn/sandpaper/releases/tag/v0.0.0
